# MyTest multiply

A small demo library about publishing libraries.

### Installation
```bash
pip install mytest-multiply
```

### Get started

How to multiply one number by another with this lib:
```python
from mytest_multiply import Multiplication

# Instantiate a Multiplication objec
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```
